<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Instalação',
'L_WRONG_PHP_VERSION'				=> 'PluXml exige a execução de PHP 5 ou superior para poder funcionar.',
'L_SELECT_LANG'						=> 'Seléccione o seu idioma',
'L_INPUT_CHANGE'					=> 'Alterar',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Rubrica 1',
'L_DEFAULT_CATEGORY_URL'			=> 'rubrica-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Stática 1',
'L_DEFAULT_STATIC_URL'				=> 'stática-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Primeiro artigo',
'L_DEFAULT_ARTICLE_URL'				=> 'primeiro-artigo',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Este é o primeiro comentário !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml já está configurado !',
'L_ERR_MISSING_USER'				=> 'Por favor, indique o nome do redactor !',
'L_ERR_MISSING_LOGIN'				=> 'Por favor, indique o login de conexão !',
'L_ERR_MISSING_PASSWORD'			=> 'Por favor, indique a sua senha !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Confirmação da senha incorrecta !',
'L_PLUXML_INSTALLATION'				=> 'Instalação de PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog ou Cms á Xml !',
'L_VERSION'							=> 'versão',
'L_USERNAME'						=> 'Nome do administrador',
'L_LOGIN'							=> 'Login de conexão à administração',
'L_PASSWORD'						=> 'Senha',
'L_PASSWORD_CONFIRMATION'			=> 'Confirmação da senha',
'L_INPUT_INSTALL'					=> 'Instalar',
'L_TIMEZONE'						=> 'Fuso horário',
'L_PWD_VERY_WEAK'					=> 'Senha muito fraca',
'L_PWD_WEAK'						=> 'Senha fraca',
'L_PWD_GOOD'						=> 'Boa senha',
'L_PWD_STRONG'						=> 'Senha forte',
);
?>
